function makeFig_RELRATIO

%{
 Data taken from "repeatability of calibration"
To plot experienced and naive observer measurements of gamma and color
ratios
experienced observers:  LT,SM,RW
naive observers:  XF,CG,CV,LM

note - when the 'date' came in for experienced, it got divided ie Sept 13 =
9/13. 

%}



commonFontSize=30;
 load naive;
load experienced;
experNames = {'LT','SM','RW'};
naiveNames = {'XF','CG','CV','LM'};
linespecList = {'-ks','-k^','-kd','-ko'};
%       SOON take out the 'Rel'.
ReltheRatioTypes = {'RelGreenOverRed','RelRedOverBlue'};

theYLabels = {'Relative Green/Red Ratio','Relative Red/Blue Ratio'};
theMarkerSize = 18;
%
%

% there will be 2 plots, one is GreenOverRed, the other is RedOverBlue
% for each plot, first plot the experienced in solid symbols, then the naive
% in open symbols
for iratio = 1:length(ReltheRatioTypes)
    %set up the figure
    theField = ReltheRatioTypes(iratio);
    theYLabel = theYLabels(iratio);
    figurehandle= figure; 
    hold on;
    
    for isubjType = 1:2
        switch isubjType
            case 1
                subjNames =experNames;
                theData = experienced;
                theMarkerFaceColor = 'k';  %filled
            case 2
                subjNames = naiveNames;
                theData = naive;
                theMarkerFaceColor = 'w';  %empty
        end
    %       loop over the subjects and put on plot
        for isubj = 1:length(subjNames)
            theName = subjNames(isubj);

            [ theDay theRatio]= unpackthedata(theName, theData, theField);
            plot(theDay, theRatio,cell2mat(linespecList(isubj)),'MarkerSize',theMarkerSize,'MarkerFaceColor',theMarkerFaceColor);
        end
        

    end
    
     %       condition the figure

     theYLimits = get(gca,'YLim');
     theXLimits = [-5 85];  theYLimits = [0.4 2];
     plot([40 40 ],theYLimits, '-k');

     set(gca,'XLim',theXLimits, 'XTick',[0,10,20,30,40,50,60,70,80]);
     
     set(gca, 'YLim', theYLimits, 'YTick', [0.5  1 1.5  2]);
     set(gca, 'YScale', 'log');
     
     %      the secondary zero is at 40.
    set(gca,'XTickLabel',{'0';'10';'20';'30';'0';'10';'20';'30';'40'},'FontSize',commonFontSize-4);
    ylabel(theYLabel);
    xlabel('Time (days)');         


    %   save the figure
        scrsz = get(0,'ScreenSize');
    set(figurehandle,'Position',[scrsz(1) -.04*scrsz(4) scrsz(3) 0.96*scrsz(4)]);   %make almost full screen

    saveas(figurehandle,[cell2mat(theField) '.tif']);   
    
    
end




 
end 

function [ theDays theRatios] = unpackthedata(theName, theData, theField)

line1 = theData(1,:);
theCol = strmatch(theField,line1);
dayCol = strmatch('day',line1);
%get the list of rows
col1 = theData(:,1);
theRows = strmatch(theName,col1);


%we might have empty cells in the data. so find out if any are and
%eliminate
tempData = theData(theRows,theCol);
%       this eliminates empty rows
emptyRows = find(cellfun(@isempty,tempData));
rowidx = 1:length(theRows);
rowidx = setdiff(rowidx,emptyRows);
theRows = theRows(rowidx);
theRows = setdiff(theRows,emptyRows);

%       this eliminates rows with zeros
tempRatios = cell2mat(theData(theRows,theCol));
idx0 = find (tempRatios==0);
rowidx = 1:length(theRows);
rowidx = setdiff(rowidx,idx0);
theRows = theRows(rowidx);

theDays = cell2mat(theData(theRows,dayCol));
theRatios = cell2mat(theData(theRows,theCol));


end
